@@ -7,8 +7,6 @@ test_that("occ works for each data source", {
   x2 <- occ(query = 'Accipiter striatus', from = 'ecoengine', limit = 30)
   x3 <- occ(query = 'Danaus plexippus', from = 'inat', limit = 30)
   x4 <- occ(query = 'Bison bison', from = 'bison', limit = 30)
-  x5 <- occ(query = 'Setophaga caerulescens', from = 'ebird', ebirdopts = list(region='US'), limit = 30)
-  x6 <- occ(query = 'Spinus tristis', from = 'ebird', ebirdopts = list(method = 'ebirdgeo', lat = 42, lng = -76, dist = 50), limit = 30)
   x7 <- occ(query = 'Spinus tristis', from = 'idigbio', limit = 30)
   
   x8 <- occ(query = 'Spinus tristis', from = 'vertnet', limit = 30)
@@ -20,8 +18,6 @@ test_that("occ works for each data source", {
   # Make sure they are all occdats
   expect_is(x3, "occdat")
   expect_is(x4, "occdat")
-  expect_is(x5, "occdat")
-  expect_is(x6, "occdat")
   expect_is(x7, "occdat")
   expect_is(x8, "occdat")
   expect_is(x9, "occdat")
@@ -45,18 +41,6 @@ test_that("occ works for each data source", {
   expect_is(x3$inat$data[[1]], "data.frame")
   temp_df3 <- x3$inat$data[[1]]
   expect_equal(unique(temp_df3$prov), "inat")
-  # Testing x5
-  expect_is(x5, "occdat")
-  expect_is(x5$ebird, "occdatind")
-  expect_is(x5$ebird$data[[1]], "data.frame")
-  temp_df4 <- x5$ebird$data[[1]]
-  expect_equal(unique(temp_df4$prov), "ebird")
-  # Testing x6
-  expect_is(x6, "occdat")
-  expect_is(x6$ebird, "occdatind")
-  expect_is(x6$ebird$data[[1]], "data.frame")
-  temp_df6 <- x6$ebird$data[[1]]
-  expect_equal(unique(temp_df6$prov), "ebird")
 
   # Testing x7
   expect_is(x7, "occdat")
